@@ -1,4 +1,6 @@
-from .number_range import NumberRange, NumberRangeException
+from .number_range import (
+    NumberRange, NumberRangeException, RangeBoundsException
+)
 from .weekday import WeekDay
 from .weekdays import WeekDays
 
@@ -6,6 +8,7 @@ from .weekdays import WeekDays
 __all__ = (
     NumberRange,
     NumberRangeException,
+    RangeBoundsException,
     WeekDay,
     WeekDays
 )
