@@ -6,8 +6,9 @@ from sqlalchemy.orm import sessionmaker
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.ext.hybrid import hybrid_property
 
-from sqlalchemy_utils import InstrumentedList
-from sqlalchemy_utils import coercion_listener
+from sqlalchemy_utils import (
+    InstrumentedList, coercion_listener, aggregates, i18n
+)
 
 
 @sa.event.listens_for(sa.engine.Engine, 'before_cursor_execute')
@@ -24,6 +25,13 @@ warnings.simplefilter('error', sa.exc.SAWarning)
 sa.event.listen(sa.orm.mapper, 'mapper_configured', coercion_listener)
 
 
+def get_locale():
+    class Locale():
+        territories = {'fi': 'Finland'}
+
+    return Locale()
+
+
 class TestCase(object):
     dns = 'sqlite:///:memory:'
 
@@ -34,12 +42,16 @@ class TestCase(object):
         self.Base = declarative_base()
 
         self.create_models()
+        sa.orm.configure_mappers()
         self.Base.metadata.create_all(self.connection)
 
         Session = sessionmaker(bind=self.connection)
         self.session = Session()
 
+        i18n.get_locale = get_locale
+
     def teardown_method(self, method):
+        aggregates.manager.reset()
         self.session.close_all()
         self.Base.metadata.drop_all(self.connection)
         self.connection.close()
